==================================================================
Common workflow language tool description reference implementation
==================================================================

This is intended to be a lightweight reference implementation of the common
workflow language tool description.

Install
-------

From source::

  git clone https://github.com/common-workflow-language/common-workflow-language.git
  cd common-workflow-language/reference
  easy_install .

With pip::

  pip install cwltool


Run on the command line
-----------------------

  ``cwltool [tool] [job]``

Use as a library
----------------

Add::

  import cwltool

to your script.
